@@ -29,7 +29,7 @@ class ConnectionError(Exception):
 class Headers(dict):
     """ Case insensitive dict build from request """
     def __init__(self, req):
-        for h in req.getAllResponseHeaders().rstrip().split("\r\n"):
+        for h in req.getAllResponseHeaders().rstrip().split("\\r\\n"):
             h = h.split(":")
             self[h[0]] = ":".join(h[1:]).lstrip()
 
